@@ -6,11 +6,12 @@ import warnings
 from functools import wraps
 
 import numpy as np
-from astropy.nddata import StdDevUncertainty, VarianceUncertainty, InverseVariance
+from astropy.nddata import VarianceUncertainty
 
 from .. import conf
 from ..spectra import Spectrum1D
 from ..manipulation import extract_region, LinearInterpolatedResampler
+from .uncertainty import _convert_uncertainty
 from .utils import computation_wrapper
 import astropy.units as u
 from astropy.stats import mad_std
@@ -135,17 +136,14 @@ def _compute_line_flux(spectrum, regions=None,
     line_flux = np.sum(flux * dx)
 
     line_flux.uncertainty = None
+    line_flux.uncertainty_type = 'stddev'
 
     if calc_spectrum.uncertainty is not None:
         # Can't handle masks via interpolation here, since interpolators
         # only work with the flux array.
-        if isinstance(calc_spectrum.uncertainty, StdDevUncertainty):
-            variance_q = calc_spectrum.uncertainty.quantity ** 2
-        elif isinstance(calc_spectrum.uncertainty, VarianceUncertainty):
-            variance_q = calc_spectrum.uncertainty.quantity
-        elif isinstance(calc_spectrum.uncertainty, InverseVariance):
-            variance_q = 1/calc_spectrum.uncertainty.quantity
-        else:
+        try:
+            variance_q = _convert_uncertainty(calc_spectrum.uncertainty, VarianceUncertainty)
+        except ValueError:
             warnings.warn(f"Uncertainty type "
                           f"'{calc_spectrum.uncertainty.uncertainty_type}' "
                           f"was not recognized by line_flux. Proceeding "
@@ -193,7 +191,18 @@ def _compute_equivalent_width(spectrum, continuum=1, regions=None,
     dx = np.abs(np.diff(spectrum.spectral_axis.bin_edges))
     ew = np.sum((1 - line_flux / cont_flux) * dx)
 
-    return ew.to(spectrum.spectral_axis.unit)
+    # NOTE: uncertainty gets lost during unit translation, so we have to convert first
+    ew = ew.to(spectrum.spectral_axis.unit)
+    if line_flux.uncertainty is not None:
+        # continuum has no uncertainty, here we assume no uncertainty on the bin edges (dx) as well
+        # we need to add the line_flux uncertainties in quadrature for the sum above (which was
+        # summed over the length of dx)
+        ew.uncertainty = np.sqrt((line_flux.uncertainty.value**2)*len(dx)) * dx.unit
+    else:
+        ew.uncertainty = None
+
+    ew.uncertainty_type = 'stddev'
+    return ew
 
 
 def is_continuum_below_threshold(spectrum, threshold=0.01):
